'''_5081.py

ConnectorCompoundModalAnalysesAtStiffnesses
'''


from mastapy.system_model.analyses_and_results.modal_analyses_at_stiffnesses_ns.compound import _5118
from mastapy._internal.python_net import python_net_import

_CONNECTOR_COMPOUND_MODAL_ANALYSES_AT_STIFFNESSES = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtStiffnessesNS.Compound', 'ConnectorCompoundModalAnalysesAtStiffnesses')


__docformat__ = 'restructuredtext en'
__all__ = ('ConnectorCompoundModalAnalysesAtStiffnesses',)


class ConnectorCompoundModalAnalysesAtStiffnesses(_5118.MountableComponentCompoundModalAnalysesAtStiffnesses):
    '''ConnectorCompoundModalAnalysesAtStiffnesses

    This is a mastapy class.
    '''

    TYPE = _CONNECTOR_COMPOUND_MODAL_ANALYSES_AT_STIFFNESSES
    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConnectorCompoundModalAnalysesAtStiffnesses.TYPE'):
        super().__init__(instance_to_wrap)
